.. _changes_0_9:

Version 0.9.1
=============

**May 16, 2022**

Changelog
---------

This release provides fixes that make `imbalanced-learn` works with the
latest release (`1.1.0`) of `scikit-learn`.

Version 0.9.0
=============

**January 11, 2022**

Changelog
---------

This release is mainly providing fixes that make `imbalanced-learn` works
with the latest release (`1.0.2`) of `scikit-learn`.
